@@ -1,8 +1,9 @@
-/*
+/*      $Id: hints.h,v 1.55 2004/11/23 23:57:33 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
-        the Free Software Foundation; You may only use version 2 of the License,
-        you have no option to use any other version.
+        the Free Software Foundation; either version 2, or (at your option)
+        any later version.
  
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +16,7 @@
  
         oroborus - (c) 2001 Ken Lynch
         Metacity - (c) 2001 Havoc Pennington
-        xfwm4    - (c) 2002-2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
@@ -31,6 +32,9 @@
 #include <X11/Xmd.h>
 #include <X11/Xatom.h>
 #include <glib.h>
+#include <gdk/gdk.h>
+
+#include "display.h"
 
 #define MWM_HINTS_ELEMENTS                      3L
 
@@ -73,6 +77,7 @@
 
 #define WM_PROTOCOLS_TAKE_FOCUS                 (1L<<0)
 #define WM_PROTOCOLS_DELETE_WINDOW              (1L<<1)
+#define WM_PROTOCOLS_CONTEXT_HELP               (1L<<2)
 
 #define WIN_LAYER_DESKTOP                       0
 #define WIN_LAYER_BELOW                         2
@@ -95,6 +100,38 @@
 #define NET_WM_STATE_ADD                        1
 #define NET_WM_STATE_TOGGLE                     2
 
+#define NET_WM_ORIENTATION_HORZ                 0
+#define NET_WM_ORIENTATION_VERT                 1
+
+#define NET_WM_TOPLEFT                          0
+#define NET_WM_TOPRIGHT                         1
+#define NET_WM_BOTTOMRIGHT                      2
+#define NET_WM_BOTTOMLEFT                       3
+
+#define NET_WM_OPAQUE                           0xffffffff
+
+typedef struct
+{
+    unsigned long orientation;
+    unsigned long start;
+    unsigned long rows;
+    unsigned long cols;
+}
+NetWmDesktopLayout;
+
+#define LEFT                            0
+#define RIGHT                           1
+#define TOP                             2
+#define BOTTOM                          3
+#define LEFT_START_Y                    4
+#define LEFT_END_Y                      5
+#define RIGHT_START_Y                   6
+#define RIGHT_END_Y                     7
+#define TOP_START_X                     8
+#define TOP_END_X                       9
+#define BOTTOM_START_X                  10
+#define BOTTOM_END_X                    11
+
 typedef struct
 {
     unsigned long flags;
@@ -103,107 +140,40 @@ typedef struct
 }
 PropMwmHints;
 
-extern Atom gnome_panel_desktop_area;
-extern Atom motif_wm_hints;
-extern Atom sm_client_id;
-extern Atom win_client_list;
-extern Atom win_desktop_button_proxy;
-extern Atom win_hints;
-extern Atom win_layer;
-extern Atom win_protocols;
-extern Atom win_state;
-extern Atom win_supporting_wm_check;
-extern Atom win_workspace;
-extern Atom win_workspace_count;
-extern Atom wm_change_state;
-extern Atom wm_client_leader;
-extern Atom wm_colormap_windows;
-extern Atom wm_delete_window;
-extern Atom wm_protocols;
-extern Atom wm_state;
-extern Atom wm_takefocus;
-extern Atom wm_window_role;
+unsigned long getWMState (DisplayInfo *, Window);
+void setWMState (DisplayInfo *, Window, unsigned long);
+PropMwmHints *getMotifHints (DisplayInfo *, Window);
+unsigned int getWMProtocols (DisplayInfo *, Window);
+gboolean getHint (DisplayInfo *, Window, int, long *);
+void setHint (DisplayInfo *, Window, int, long);
+void getDesktopLayout (DisplayInfo *, Window, int, NetWmDesktopLayout *);
+void getGnomeDesktopMargins (DisplayInfo *, Window, int *);
+void setGnomeProtocols (DisplayInfo *, Window, Window);
+void setNetSupportedHint (DisplayInfo *, Window, Window);
+gboolean getAtomList (DisplayInfo *, Window, int, Atom **, int *);
+gboolean getCardinalList (DisplayInfo *, Window, int, unsigned long **, int *);
+void setNetWorkarea (DisplayInfo *, Window, int, int, int, int *);
+void setNetFrameExtents (DisplayInfo *, Window, int, int, int, int);
+void initNetDesktopInfo (DisplayInfo *, Window, int, int, int);
+void setUTF8StringHint (DisplayInfo *, Window, int, const char *);
+void getTransientFor (DisplayInfo *, Window, Window, Window *);
+void getWindowName (DisplayInfo *, Window, char **);
+gboolean getUTF8String (DisplayInfo *, Window, int, char **, int *);
+void getWindowName (DisplayInfo *, Window, char **);
+gboolean checkKdeSystrayWindow(DisplayInfo *, Window);
+void sendSystrayReqDock(DisplayInfo *, Window, Window);
+Window getSystrayWindow (DisplayInfo *, Atom);
+gboolean getWindowRole (DisplayInfo *, Window, char **);
+Window getClientLeader (DisplayInfo *, Window);
+gboolean getNetWMUserTime (DisplayInfo *, Window, Time *);
+gboolean getClientID (DisplayInfo *, Window, char **);
+gboolean getWindowCommand (DisplayInfo *, Window, char ***, int *);
+gboolean getKDEIcon (DisplayInfo *, Window, Pixmap *, Pixmap *);
+gboolean getRGBIconData (DisplayInfo *, Window, unsigned long **, unsigned long *);
+gboolean getOpacity (DisplayInfo *, Window, guint *);
 
-/* freedesktop.org protocol */
-
-extern Atom net_active_window;
-extern Atom net_client_list;
-extern Atom net_client_list_stacking;
-extern Atom net_close_window;
-extern Atom net_current_desktop;
-extern Atom net_desktop_geometry;
-extern Atom net_desktop_viewport;
-extern Atom net_number_of_desktops;
-extern Atom net_startup_id;
-extern Atom net_supported;
-extern Atom net_supporting_wm_check;
-extern Atom net_wm_action_change_desktop;
-extern Atom net_wm_action_close;
-extern Atom net_wm_action_maximize_horz;
-extern Atom net_wm_action_maximize_vert;
-extern Atom net_wm_action_move;
-extern Atom net_wm_action_resize;
-extern Atom net_wm_action_shade;
-extern Atom net_wm_action_stick;
-extern Atom net_wm_allowed_actions;
-extern Atom net_wm_desktop;
-extern Atom net_wm_icon;
-extern Atom net_wm_icon_geometry;
-extern Atom net_wm_icon_name;
-extern Atom net_wm_moveresize;
-extern Atom net_wm_name;
-extern Atom net_wm_state;
-extern Atom net_wm_state_above;
-extern Atom net_wm_state_below;
-extern Atom net_wm_state_fullscreen;
-extern Atom net_wm_state_hidden;
-extern Atom net_wm_state_maximized_horz;
-extern Atom net_wm_state_maximized_vert;
-extern Atom net_wm_state_modal;
-extern Atom net_wm_state_shaded;
-extern Atom net_wm_state_skip_pager;
-extern Atom net_wm_state_skip_taskbar;
-extern Atom net_wm_state_sticky;
-extern Atom net_wm_strut;
-extern Atom net_wm_window_type;
-extern Atom net_wm_window_type_desktop;
-extern Atom net_wm_window_type_dialog;
-extern Atom net_wm_window_type_dock;
-extern Atom net_wm_window_type_menu;
-extern Atom net_wm_window_type_normal;
-extern Atom net_wm_window_type_splashscreen;
-extern Atom net_wm_window_type_toolbar;
-extern Atom net_wm_window_type_utility;
-extern Atom net_workarea;
-
-void initICCCMHints (Display *);
-unsigned long getWMState (Display *, Window);
-void setWMState (Display *, Window, unsigned long);
-void initMotifHints (Display *);
-PropMwmHints *getMotifHints (Display *, Window);
-unsigned int getWMProtocols (Display *, Window);
-void initGnomeHints (Display *);
-gboolean getHint (Display *, Window, Atom, long *);
-void setHint (Display *, Window, Atom, long);
-void getGnomeDesktopMargins (Display *, int, int *);
-void setGnomeProtocols (Display *, int, Window);
-void initNetHints (Display * dpy);
-void set_net_supported_hint (Display *, int, Window);
-gboolean get_atom_list (Display *, Window, Atom, Atom **, int *);
-gboolean get_cardinal_list (Display *, Window, Atom, unsigned long **, int *);
-void set_net_workarea (Display *, int, int, int *);
-void init_net_desktop_params (Display *, int, int);
-void set_utf8_string_hint (Display *, Window, Atom, const char *);
-void getTransientFor (Display *, int, Window, Window *);
-void getWindowName (Display *, Window, char **);
-gboolean get_utf8_string (Display *, Window, Atom, char **);
-void getWindowName (Display *, Window, char **);
-gboolean getWindowRole (Display *, Window, char **);
-Window getClientLeader (Display *, Window);
-gboolean getClientID (Display *, Window, char **);
-gboolean getWindowCommand (Display *, Window, char ***, int *);
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
-gboolean getWindowStartupId (Display *, Window, char **);
+gboolean getWindowStartupId (DisplayInfo *, Window, char **);
 #endif
 
 #endif /* INC_HINTS_H */
