@@ -1,8 +1,9 @@
-/*
+/*      $Id: keyboard.h,v 1.13 2004/08/22 22:18:50 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
-        the Free Software Foundation; You may only use version 2 of the License,
-        you have no option to use any other version.
+        the Free Software Foundation; either version 2, or (at your option)
+        any later version.
  
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +15,7 @@
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
@@ -27,12 +28,12 @@
 
 #include <X11/keysym.h>
 
-typedef struct
+typedef struct _MyKey             MyKey;
+struct _MyKey
 {
     KeyCode keycode;
     int modifier;
-}
-MyKey;
+};
 
 extern unsigned int KeyMask;
 extern unsigned int ButtonMask;
@@ -48,6 +49,8 @@ extern unsigned int HyperMask;
 void parseKeyString (Display *, MyKey *, char *);
 void grabKey (Display *, MyKey *, Window);
 void ungrabKeys (Display *, Window);
+void grabButton (Display *, int, int, Window);
+void ungrabButton (Display *, int, int, Window);
 void initModifiers (Display *);
 
 #endif /* INC_KEYBOARD_H */
