@@ -1,8 +1,9 @@
-/*
+/*      $Id: parserc.h,v 1.17 2004/09/21 19:27:01 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
-        the Free Software Foundation; You may only use version 2 of the License,
-        you have no option to use any other version.
+        the Free Software Foundation; either version 2, or (at your option)
+        any later version.
  
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +15,7 @@
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
@@ -34,7 +35,8 @@ gchar *getValue (const gchar *, Settings rc[]);
 gboolean setValue (const gchar *, const gchar *, Settings rc[]);
 gboolean setBooleanValueFromInt (const gchar *, int, Settings rc[]);
 gboolean setIntValueFromInt (const gchar *, int, Settings rc[]);
-gchar *getThemeDir (const gchar *);
+gchar *getSystemThemeDir (void);
+gchar *getThemeDir (const gchar *, const gchar *);
 void freeRc (Settings rc[]);
 
 #endif /* INC_PARSERC_H */
