@@ -1,8 +1,9 @@
-/*
+/*      $Id: settings.h,v 1.48 2004/11/30 23:26:10 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
-        the Free Software Foundation; You may only use version 2 of the License,
-        you have no option to use any other version.
+        the Free Software Foundation; either version 2, or (at your option)
+        any later version.
  
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,30 +15,23 @@
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
-#ifndef INC_SETTINGS_H
-#define INC_SETTINGS_H
-
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
 
 #include <glib.h>
 #include <gdk/gdk.h>
+#include "screen.h"
 #include "keyboard.h"
 #include "mypixmap.h"
+#include "hints.h"
 
-#define CORNER_TOP_LEFT                 0
-#define CORNER_TOP_RIGHT                1
-#define CORNER_BOTTOM_LEFT              2
-#define CORNER_BOTTOM_RIGHT             3
-
-#define SIDE_LEFT                       0
-#define SIDE_RIGHT                      1
-#define SIDE_BOTTOM                     2
+#ifndef INC_SETTINGS_H
+#define INC_SETTINGS_H
 
 #define TITLE_1                         0
 #define TITLE_2                         1
@@ -111,9 +105,18 @@
 #define KEY_SHORTCUT_8                  47
 #define KEY_SHORTCUT_9                  48
 #define KEY_SHORTCUT_10                 49
-#define KEY_LOWER_WINDOW		50
-#define KEY_RAISE_WINDOW		51
-#define KEY_COUNT                       52
+#define KEY_LOWER_WINDOW                50
+#define KEY_RAISE_WINDOW                51
+#define KEY_TOGGLE_FULLSCREEN           52
+#define KEY_UP_WORKSPACE                53
+#define KEY_DOWN_WORKSPACE              54
+#define KEY_LEFT_WORKSPACE              55
+#define KEY_RIGHT_WORKSPACE             56
+#define KEY_MOVE_UP_WORKSPACE           57
+#define KEY_MOVE_DOWN_WORKSPACE         58
+#define KEY_MOVE_LEFT_WORKSPACE         59
+#define KEY_MOVE_RIGHT_WORKSPACE        60
+#define KEY_COUNT                       61
 #define NB_KEY_SHORTCUTS                10
 
 #define ALIGN_LEFT                      0
@@ -125,15 +128,13 @@
 #define ACTION_SHADE                    2
 #define ACTION_HIDE                     3
 
-typedef struct _MyColor MyColor;
-struct _MyColor
+struct _XfwmColor
 {
     GdkColor col;
     GdkGC *gc;
     gboolean allocated;
 };
 
-typedef struct _Settings Settings;
 struct _Settings
 {
     gchar *option;
@@ -141,55 +142,56 @@ struct _Settings
     gboolean required;
 };
 
-typedef struct _Params Params;
-struct _Params
+struct _XfwmParams
 {
-    MyColor title_colors[2];
     MyKey keys[KEY_COUNT];
-    MyPixmap buttons[BUTTON_COUNT][6];
-    MyPixmap corners[4][2];
-    MyPixmap sides[3][2];
-    MyPixmap title[5][2];
     gchar button_layout[8];
     gchar *shortcut_exec[NB_KEY_SHORTCUTS];
     unsigned int xfwm_margins[4];
     int button_offset;
     int button_spacing;
-    int dbl_click_time;
     int double_click_action;
+    int move_opacity;
+    int resize_opacity;
     int raise_delay;
     int snap_width;
+    int shadow_delta_x;
+    int shadow_delta_y;
+    int shadow_delta_width;
+    int shadow_delta_height;
     int title_alignment;
     int title_horizontal_offset;
-    int workspace_count;
     int wrap_resistance;
     gboolean title_shadow[2];
-    gboolean cycle_minimum;
     gboolean box_move;
     gboolean box_resize;
     gboolean click_to_focus;
+    gboolean cycle_hidden;
+    gboolean cycle_minimum;
     gboolean easy_click;
     gboolean focus_hint;
     gboolean focus_new;
     gboolean full_width_title;
+    gboolean prevent_focus_stealing;
     gboolean raise_on_click;
     gboolean raise_on_focus;
+    gboolean raise_with_any_button;
+    gboolean scroll_workspaces;
     gboolean snap_to_border;
     gboolean snap_to_windows;
     gboolean title_vertical_offset_active;
     gboolean title_vertical_offset_inactive;
-    gboolean wrap_workspaces;
+    gboolean toggle_workspaces;
+    gboolean wrap_cycle;
+    gboolean wrap_layout;
     gboolean wrap_windows;
-    GC box_gc;
-    GdkGC *black_gc;
-    GdkGC *white_gc;
+    gboolean wrap_workspaces;
 };
 
-extern Params params;
-
-gboolean loadSettings (void);
-void unloadSettings (void);
-gboolean reloadSettings (int);
-gboolean initSettings (void);
+gboolean loadSettings   (ScreenInfo *);
+gboolean reloadSettings (DisplayInfo *, 
+                         int);
+gboolean initSettings   (ScreenInfo *);
+void     closeSettings  (ScreenInfo *);
 
 #endif /* INC_SETTINGS_H */
