@@ -1,9 +1,10 @@
-/*
+/*      $Id: tabwin.h,v 1.14 2004/08/22 22:18:50 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
-        the Free Software Foundation; You may only use version 2 of the License,
-        you have no option to use any other version.
- 
+        the Free Software Foundation; either version 2, or (at your option)
+        any later version.
+        
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
         MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -13,7 +14,7 @@
         along with this program; if not, write to the Free Software
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
-        xfwm4    - (c) 2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
@@ -26,18 +27,19 @@
 
 #include <glib.h>
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
 typedef struct _Tabwin Tabwin;
 struct _Tabwin
 {
     GtkWidget *window;
+    GtkWidget *image;
+    GtkWidget *class;
     GtkWidget *label;
 };
 
-Tabwin *tabwinCreate (gchar * label);
-void tabwinSetLabel (Tabwin * tabwin, gchar * label);
-void tabwinDestroy (Tabwin * tabwin);
+Tabwin *tabwinCreate (GdkScreen *, GdkPixbuf *, const gchar *, const gchar *);
+void tabwinSetLabel (Tabwin *, GdkPixbuf *, const gchar *, const gchar *);
+void tabwinDestroy (Tabwin *);
 
 #endif /* INC_TABWIN_H */
