@@ -1,8 +1,9 @@
-/*
+/*      $Id: workspaces.h,v 1.22 2004/10/08 20:36:07 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
-        the Free Software Foundation; You may only use version 2 of the License,
-        you have no option to use any other version.
+        the Free Software Foundation; either version 2, or (at your option)
+        any later version.
  
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +15,7 @@
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
@@ -28,11 +29,14 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xmd.h>
+#include <glib.h>
+#include "screen.h"
 #include "client.h"
 
-void workspaceSwitch (int, Client *);
-void workspaceSetCount (int);
-void workspaceGetArea (int *, int *, Client *);
-void workspaceUpdateArea (int *, int *);
+gboolean workspaceMove (ScreenInfo *, int, int, Client *);
+void workspaceSwitch (ScreenInfo *, int, Client *);
+void workspaceSetNames (ScreenInfo *, char *, int);
+void workspaceSetCount (ScreenInfo *, int);
+void workspaceUpdateArea (ScreenInfo *);
 
 #endif /* INC_WORKSPACES_H */
